# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`strongswan`](#strongswan): Manage strongswan service via vici/swanctl.

### Defined types

* [`strongswan::xfrm`](#strongswanxfrm): Create interface file for xfrm device.

### Functions

* [`strongswan::extract_xfrm_devices_from_connections`](#strongswanextract_xfrm_devices_from_connections): Build strongswan::xfrm resource hashes from connections. Get if_id(_in/_out) from each connection. For each if_id, create one xfrm resrouces.
* [`strongswan::hash_to_strongswan_config`](#strongswanhash_to_strongswan_config)

## Classes

### <a name="strongswan"></a>`strongswan`

Besides ensuring that strongswan-swantcl is installed active and the stroke-based
service is disabled, this module writes strongswan.conf and swanctl.conf. If route based
is enabled, xfrm interfaces are also managed.

#### Examples

##### 

```puppet
include strongswan
```

#### Parameters

The following parameters are available in the `strongswan` class:

* [`aikgen`](#aikgen)
* [`attest`](#attest)
* [`charon`](#charon)
* [`charon_mm`](#charon_mm)
* [`charon_systemd`](#charon_systemd)
* [`imv_policy_manager`](#imv_policy_manager)
* [`libimcs`](#libimcs)
* [`libtls`](#libtls)
* [`libtnccs`](#libtnccs)
* [`manager`](#manager)
* [`medcli`](#medcli)
* [`medsrv`](#medsrv)
* [`pki`](#pki)
* [`pool`](#pool)
* [`pt_tls_client`](#pt_tls_client)
* [`sec_updater`](#sec_updater)
* [`sw_collector`](#sw_collector)
* [`starter`](#starter)
* [`swanctl`](#swanctl)
* [`authorities`](#authorities)
* [`connections`](#connections)
* [`secrets`](#secrets)
* [`pools`](#pools)
* [`route_based`](#route_based)
* [`xfrm_default_base_interface`](#xfrm_default_base_interface)

##### <a name="aikgen"></a>`aikgen`

Data type: `Hash`

aikgen block in strongswan.conf.

Default value: `{}`

##### <a name="attest"></a>`attest`

Data type: `Hash`

attest block in strongswan.conf.

Default value: `{}`

##### <a name="charon"></a>`charon`

Data type: `Hash`

charon block in strongswan.conf.

Default value: `{}`

##### <a name="charon_mm"></a>`charon_mm`

Data type: `Hash`

charon-mm block in strongswan.conf.

Default value: `{}`

##### <a name="charon_systemd"></a>`charon_systemd`

Data type: `Hash`

charon-systemd block in strongswan.conf.

Default value: `{}`

##### <a name="imv_policy_manager"></a>`imv_policy_manager`

Data type: `Hash`

imv_policy_manager block in strongswan.conf.

Default value: `{}`

##### <a name="libimcs"></a>`libimcs`

Data type: `Hash`

libimcs block in strongswan.conf.

Default value: `{}`

##### <a name="libtls"></a>`libtls`

Data type: `Hash`

libtls block in strongswan.conf.

Default value: `{}`

##### <a name="libtnccs"></a>`libtnccs`

Data type: `Hash`

libtnccs block in strongswan.conf.

Default value: `{}`

##### <a name="manager"></a>`manager`

Data type: `Hash`

manager block in strongswan.conf.

Default value: `{}`

##### <a name="medcli"></a>`medcli`

Data type: `Hash`

medcli block in strongswan.conf.

Default value: `{}`

##### <a name="medsrv"></a>`medsrv`

Data type: `Hash`

medsrv block in strongswan.conf.

Default value: `{}`

##### <a name="pki"></a>`pki`

Data type: `Hash`

pki block in strongswan.conf.

Default value: `{}`

##### <a name="pool"></a>`pool`

Data type: `Hash`

pool block in strongswan.conf.

Default value: `{}`

##### <a name="pt_tls_client"></a>`pt_tls_client`

Data type: `Hash`

pt-tls-client block in strongswan.conf.

Default value: `{}`

##### <a name="sec_updater"></a>`sec_updater`

Data type: `Hash`

sec-updater block in strongswan.conf.

Default value: `{}`

##### <a name="sw_collector"></a>`sw_collector`

Data type: `Hash`

sw-collector block in strongswan.conf.

Default value: `{}`

##### <a name="starter"></a>`starter`

Data type: `Hash`

starter block in strongswan.conf.

Default value: `{}`

##### <a name="swanctl"></a>`swanctl`

Data type: `Hash`

swanctl block in strongswan.conf.

Default value: `{}`

##### <a name="authorities"></a>`authorities`

Data type: `Hash`

authorities block in swanctl.conf.

Default value: `{}`

##### <a name="connections"></a>`connections`

Data type: `Hash`

connections block in swanctl.conf. Besides keys allowed in swanctl, these ones are added:
* base_interface: base interface for xfrm device.
* if_id: interface ID for xfrm device used for in and out. In swanctl.conf, this value is used for id_id_in and if_id_out.

Default value: `{}`

##### <a name="secrets"></a>`secrets`

Data type: `Hash`

secrets block in swanctl.conf.

Default value: `{}`

##### <a name="pools"></a>`pools`

Data type: `Hash`

pools block in swanctl.conf.

Default value: `{}`

##### <a name="route_based"></a>`route_based`

Data type: `Boolean`

Whether route based VPN is configured.

Default value: ``false``

##### <a name="xfrm_default_base_interface"></a>`xfrm_default_base_interface`

Data type: `String`

XRFM base interface used if none is specified in connection.

Default value: `'lo'`

## Defined types

### <a name="strongswanxfrm"></a>`strongswan::xfrm`

Create interface file for xfrm device.

#### Parameters

The following parameters are available in the `strongswan::xfrm` defined type:

* [`base_interface`](#base_interface)
* [`routes`](#routes)
* [`interface_id`](#interface_id)

##### <a name="base_interface"></a>`base_interface`

Data type: `String`

Interface used as PHYS_DEV for xfrm interface.

##### <a name="routes"></a>`routes`

Data type: `Array`

Array of networks which are routed onto the xfrm interface.

##### <a name="interface_id"></a>`interface_id`

Data type: `Integer`

IF_ID of the interface (required to match IPSec policy).

## Functions

### <a name="strongswanextract_xfrm_devices_from_connections"></a>`strongswan::extract_xfrm_devices_from_connections`

Type: Ruby 4.x API

Build strongswan::xfrm resource hashes from connections.
Get if_id(_in/_out) from each connection. For each if_id, create one xfrm resrouces.
Add routes for all children on out interfaces

#### `strongswan::extract_xfrm_devices_from_connections(Hash $connections, String $default_base_interface)`

Build strongswan::xfrm resource hashes from connections.
Get if_id(_in/_out) from each connection. For each if_id, create one xfrm resrouces.
Add routes for all children on out interfaces

Returns: `Any`

##### `connections`

Data type: `Hash`



##### `default_base_interface`

Data type: `String`



### <a name="strongswanhash_to_strongswan_config"></a>`strongswan::hash_to_strongswan_config`

Type: Ruby 4.x API

The strongswan::hash_to_strongswan_config function.

#### `strongswan::hash_to_strongswan_config(Hash $data)`

The strongswan::hash_to_strongswan_config function.

Returns: `Any`

##### `data`

Data type: `Hash`



