# Build strongswan::xfrm resource hashes from connections.
# Get if_id(_in/_out) from each connection. For each if_id, create one xfrm resrouces.
# Add routes for all children on out interfaces
Puppet::Functions.create_function(:'strongswan::extract_xfrm_devices_from_connections') do
  dispatch :extract_xfrm_devices_from_connections do
    param 'Hash', :connections
    param 'String', :default_base_interface
  end

  def extract_xfrm_devices_from_connections(connections, default_base_interface)
    devices = {}
    connections.each do |name, data|
      # if if_id is set, set if_id_in and if_id_out, fail if there are already specified.
      if (if_id = data.delete('if_id'))
        raise Puppet::Error, "get_xfrm_devices_from_connections: connection #{name} if_id and if_id_out set, set only one" if data.key?('if_id_out')
        raise Puppet::Error, "get_xfrm_devices_from_connections: connection #{name} if_id and if_id_in set, set only one" if data.key?('if_id_in')
        if_id_in = data['if_id_in'] = if_id
        if_id_out = data['if_id_out'] = if_id
      elsif !(if_id_in = data['if_id_in']) || !(if_id_out = data['if_id_out'])
        raise Puppet::Error, "get_xfrm_devices_from_connections: connection #{name}: route_based without if_id, set either if_id oder if_id_in and if_id_out"\
      end
      base_interface = data.delete('base_interface') || default_base_interface
      # out device
      devname = "ipsec#{if_id_out}"
      routes = data['children'].values.map { |childdata| childdata['remote_ts'] }.flatten
      if (d = devices[devname])
        d['routes'] += routes
        d['routes'].uniq!
      else
        devices[devname] = {
          'base_interface' => base_interface,
          'routes' => routes,
          'interface_id' => if_id_out,
        }
      end
      next if if_id_out == if_id_in
      # in device if this has another id
      devname = "ipsec#{if_id_in}"
      next if devices[devname]
      devices[devname] = {
        'base_interface' => base_interface,
        'routes' => [],
        'interface_id' => if_id_in,
      }
    end
    {
      'connections' => connections,
      'xfrm' => devices,
    }
  end
end
